@@ -3,7 +3,7 @@ import sys
 import inspect
 import logging
 
-from flask import Flask, g, request, json
+from flask import Flask, g, request
 from datetime import timedelta
 from logging.handlers import WatchedFileHandler
 from cachelib import MemcachedCache, SimpleCache
@@ -12,7 +12,6 @@ from uuid import uuid4
 from . import ctx
 from .errors import handle_api_error, handle_other_errors, ApiError
 from .sessions import MongoSessionInterface
-from .json_encoder import MongoJSONEncoder
 from .queue import RedisQueue, MongoQueue, DummyQueue
 from .uorm.db import db
 
@@ -180,8 +179,6 @@ class Base:
             for k, v in ctx.cfg.get("flask_settings").items():
                 flask.config[k] = v
         flask.secret_key = ctx.cfg.get("app_secret_key")
-        ctx.log.debug("Setting up JSON encoder")
-        json.JSONEncoder = MongoJSONEncoder
 
         # pylint: disable=unused-variable
         @flask.before_request
