@@ -1,3 +1,4 @@
+from typing import Dict, Callable, Any, Set, List
 from .fields import Field
 
 
@@ -15,13 +16,13 @@ def snake_case(name):
 
 class MetaModel:
 
-    __fields__ = None
-    __rejected_fields__ = None
-    __restricted_fields__ = None
-    __validators__ = None
-    __def_values__ = None
-    __def_indexes__ = None
-    __cache_key_fields__ = None
+    __fields__: Set = None
+    __rejected_fields__: Set = None
+    __restricted_fields__: Set = None
+    __validators__: Dict[str, Callable[[Any], None]] = None
+    __def_values__: Dict[str, Any] = None
+    __def_indexes__: List = None
+    __cache_key_fields__: Set = None
 
     COLLECTION = None
     INDEXES = None
@@ -33,23 +34,29 @@ class MetaModel:
     def __init_subclass__(cls, **kwargs):
         super().__init_subclass__(**kwargs)
         cls.__fields__ = set() if cls.__fields__ is None else cls.__fields__.copy()
+
         cls.__def_values__ = (
             {} if cls.__def_values__ is None else cls.__def_values__.copy()
         )
+
         cls.__validators__ = (
             {} if cls.__validators__ is None else cls.__validators__.copy()
         )
+
         cls.__rejected_fields__ = (
             set() if cls.__rejected_fields__ is None else cls.__rejected_fields__.copy()
         )
+
         cls.__restricted_fields__ = (
             set()
             if cls.__restricted_fields__ is None
             else cls.__restricted_fields__.copy()
         )
+
         cls.__def_indexes__ = (
             [] if cls.__def_indexes__ is None else cls.__def_indexes__[:]
         )
+
         cls.__cache_key_fields__ = (
             {"_id"}
             if cls.__cache_key_fields__ is None
