@@ -1,10 +1,11 @@
-import logging
+from typing import Dict, Any, Union
 from functools import partial
 from time import time
 from .base_model import BaseModel
-from ..db import db
+from ..db import db, ObjectsCursor
 from ..utils import save_required, resolve_id, ObjectId
 from ..errors import ModelDestroyed
+from pymongo.cursor import Cursor
 from glasskit.errors import NotFound
 from glasskit import ctx
 
@@ -14,10 +15,10 @@ class StorableModel(BaseModel):
     def _db(self):
         return db.meta
 
-    def _save_to_db(self):
+    def _save_to_db(self) -> None:
         self._db.save_obj(self)
 
-    def update(self, data, skip_callback=False, invalidate_cache=True):
+    def update(self, data, skip_callback=False, invalidate_cache=True) -> 'StorableModel':
         for field in self.__fields__:
             if (
                 field in data
@@ -25,10 +26,10 @@ class StorableModel(BaseModel):
                 and field != "_id"
             ):
                 self.__dict__[field] = data[field]
-        self.save(skip_callback=skip_callback, invalidate_cache=invalidate_cache)
+        return self.save(skip_callback=skip_callback, invalidate_cache=invalidate_cache)
 
     @save_required
-    def db_update(self, update, when=None, reload=True, invalidate_cache=True):
+    def db_update(self, update, when=None, reload=True, invalidate_cache=True) -> bool:
         """
                 :param update: MongoDB update query
                 :param when: filter query. No update will happen if it does not match
@@ -46,13 +47,13 @@ class StorableModel(BaseModel):
 
         return bool(new_data)
 
-    def _delete_from_db(self):
+    def _delete_from_db(self) -> None:
         self._db.delete_obj(self)
 
-    def _refetch_from_db(self):
+    def _refetch_from_db(self) -> 'StorableModel':
         return self.find_one({"_id": self._id})
 
-    def reload(self):
+    def reload(self) -> None:
         if self.is_new:
             return
         tmp = self._refetch_from_db()
@@ -62,11 +63,11 @@ class StorableModel(BaseModel):
 
     @classmethod
     # E.g. override if you want model to always return a subset of documents in its collection
-    def _preprocess_query(cls, query):
+    def _preprocess_query(cls, query) -> Dict[str, Any]:
         return query
 
     @classmethod
-    def find(cls, query=None, **kwargs):
+    def find(cls, query=None, **kwargs) -> ObjectsCursor:
         if not query:
             query = {}
         return db.meta.get_objs(
@@ -74,14 +75,14 @@ class StorableModel(BaseModel):
         )
 
     @classmethod
-    def aggregate(cls, pipeline, query=None, **kwargs):
+    def aggregate(cls, pipeline, query=None, **kwargs) -> Cursor:
         if not query:
             query = {}
         pipeline = [{"$match": cls._preprocess_query(query)}] + pipeline
         return db.meta.get_aggregated(cls.collection, pipeline, **kwargs)
 
     @classmethod
-    def find_projected(cls, query=None, projection=("_id",), **kwargs):
+    def find_projected(cls, query=None, projection=("_id",), **kwargs) -> Cursor:
         if not query:
             query = {}
         return db.meta.get_objs_projected(
@@ -92,13 +93,13 @@ class StorableModel(BaseModel):
         )
 
     @classmethod
-    def find_one(cls, query, **kwargs):
+    def find_one(cls, query, **kwargs) -> 'StorableModel':
         return db.meta.get_obj(
             cls._ctor, cls.collection, cls._preprocess_query(query), **kwargs
         )
 
     @classmethod
-    def get(cls, expression, raise_if_none=None):
+    def get(cls, expression, raise_if_none=None) -> Union['StorableModel', None]:
         if expression is None:
             return None
 
@@ -117,25 +118,25 @@ class StorableModel(BaseModel):
         return res
 
     @classmethod
-    def destroy_all(cls):
+    def destroy_all(cls) -> None:
         db.meta.delete_query(cls.collection, cls._preprocess_query({}))
 
     @classmethod
-    def destroy_many(cls, query):
+    def destroy_many(cls, query) -> None:
         # warning: being a faster method than traditional model manipulation,
         # this method doesn't provide any lifecycle callback for independent
         # objects
         db.meta.delete_query(cls.collection, cls._preprocess_query(query))
 
     @classmethod
-    def update_many(cls, query, attrs):
+    def update_many(cls, query, attrs) -> None:
         # warning: being a faster method than traditional model manipulation,
         # this method doesn't provide any lifecycle callback for independent
         # objects
         db.meta.update_query(cls.collection, cls._preprocess_query(query), attrs)
 
     @classmethod
-    def cache_get(cls, expression, raise_if_none=None):
+    def cache_get(cls, expression, raise_if_none=None) -> Union['StorableModel', None]:
         if expression is None:
             return None
         cache_key = f"{cls.collection}.{expression}"
@@ -143,7 +144,7 @@ class StorableModel(BaseModel):
         return cls._cache_get(cache_key, getter)
 
     @classmethod
-    def _cache_get(cls, cache_key, getter, ctor=None):
+    def _cache_get(cls, cache_key, getter, ctor=None) -> Union['StorableModel', None]:
         t1 = time()
         if not ctor:
             ctor = cls
@@ -175,15 +176,14 @@ class StorableModel(BaseModel):
         ctx.log.debug("%s miss %s %.3f secs", db.l2c.__class__.__name__, cache_key, td)
         return obj
 
-    def invalidate(self):
-        if self.USE_INITIAL_STATE:
-            for field in self.__cache_key_fields__:
-                value = self._initial_state.get(field)
-                if value:
-                    self._invalidate(f"{self.collection}.{value}")
+    def invalidate(self) -> None:
+        for field in self.__cache_key_fields__:
+            value = self._initial_state.get(field)
+            if value:
+                self._invalidate(f"{self.collection}.{value}")
 
     @staticmethod
-    def _invalidate(cache_key):
+    def _invalidate(cache_key) -> None:
         if db.l1c.delete(cache_key):
             ctx.log.debug("%s delete %s", db.l1c.__class__.__name__, cache_key)
         if db.l2c.delete(cache_key):
