@@ -4,6 +4,7 @@ from datetime import datetime
 from bson.objectid import ObjectId, InvalidId
 from urllib.parse import urlencode, unquote, urlparse, parse_qsl, ParseResult
 from uuid import uuid4
+from . import json
 
 
 def get_py_files(directory):
@@ -117,7 +118,6 @@ def add_url_params(url, params):
     Taken from https://stackoverflow.com/questions/2506379/add-params-to-given-url-in-python
     Thanks to Sapphire64
     """
-    from flask import json
 
     url = unquote(url)
     parsed_url = urlparse(url)
